==> libpsmoveapi_4.0.1.orig.tar.gz: libpsmoveapi-4.0.1/examples/labs/paint/main.cpp <==

 /**
 * PS Move API - An interface for the PS Move Motion Controller
 * Copyright (c) 2012 Thomas Perl <m@thp.io>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 **/


#include <QtGui>
#include "paintview.h"
#include "orientation.h"

int main(int argc, char **argv)
{
    QApplication app(argc, argv);

    Orientation orientation;
    orientation.start();

    int width, height;
    orientation.get_size(width, height);

    PaintView view(NULL, width, height);

    QObject::connect(&orientation, SIGNAL(newposition(int,qreal,qreal,qreal,qreal)),
            &view, SLOT(newposition(int,qreal,qreal,qreal,qreal)));
    QObject::connect(&orientation, SIGNAL(newcolor(int,int,int,int)),
            &view, SLOT(newcolor(int,int,int,int)));
    QObject::connect(&orientation, SIGNAL(backup_frame()),
            &view, SLOT(backup_frame()));
    QObject::connect(&orientation, SIGNAL(restore_frame()),
            &view, SLOT(restore_frame()));
    QObject::connect(&orientation, SIGNAL(newimage(void*)),
            &view, SLOT(newimage(void*)));

    view.show();

    return app.exec();
}

==> libpsmoveapi_4.0.12.orig.tar.gz: libpsmoveapi-4.0.12/examples/labs/paint/main.cpp <==

 /**
 * PS Move API - An interface for the PS Move Motion Controller
 * Copyright (c) 2012 Thomas Perl <m@thp.io>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 **/


#include <QtGui>
#include "paintview.h"
#include "orientation.h"

int main(int argc, char **argv)
{
    QApplication app(argc, argv);

    Orientation orientation;
    orientation.start();

    int width, height;
    orientation.get_size(width, height);

    PaintView view(NULL, width, height);

    QObject::connect(&orientation, SIGNAL(newposition(int,qreal,qreal,qreal,qreal)),
            &view, SLOT(newposition(int,qreal,qreal,qreal,qreal)));
    QObject::connect(&orientation, SIGNAL(newcolor(int,int,int,int)),
            &view, SLOT(newcolor(int,int,int,int)));
    QObject::connect(&orientation, SIGNAL(backup_frame()),
            &view, SLOT(backup_frame()));
    QObject::connect(&orientation, SIGNAL(restore_frame()),
            &view, SLOT(restore_frame()));
    QObject::connect(&orientation, SIGNAL(newimage(IplImage *)),
            &view, SLOT(newimage(IplImage *)));

    view.show();

    return app.exec();
}
